# -*- coding: utf-8 -*-
import os
import subprocess

import dj_database_url


def main():
    # Get env vars
    p1 = subprocess.Popen(['scalingo', 'run', 'env'], stdout=subprocess.PIPE)
    p2 = subprocess.Popen(
        ['grep', 'postgres://'],
        stdin=p1.stdout,
        stdout=subprocess.PIPE
    )
    p1.stdout.close()
    output, err = p2.communicate()

    # Get db_url
    db_url = output.decode("utf-8").split('=')[1].split('\r\n')[0]

    # Parse db_url
    db_config = dj_database_url.parse(db_url)

    # Construct dump command
    command = "dbclient-fetcher postgresql > /dev/null; "
    command += "PGPASSWORD={PASSWORD} "
    command += "pg_dump --clean --host {HOST} --port {PORT} "
    command += "--username {USER} "
    command += "--no-owner --no-privileges "
    command += "--exclude-schema \'information_schema\' "
    command += "--exclude-schema '^pg_*' --dbname {NAME}"
    command = '"' + command + '"'
    command = command.format(**db_config)

    # Dump database
    result = os.popen("scalingo run " + command).read()
    print(result)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_scalpg_dump
----------------------------------

Tests for `scalpg_dump` module.
"""


import unittest


class TestScalpg_dump(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_000_something(self):
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'dj_database_url',
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='scalpg_dump',
    version='0.1.0',
    description="Dumps your Scalingo PostgreSQL database without the hustle",
    long_description=readme + '\n\n' + history,
    author="Tobias Englert",
    author_email='tobias@englert.it',
    url='https://github.com/tobiase/scalpg_dump',
    packages=[
        'scalpg_dump',
    ],
    package_dir={
        'scalpg_dump': 'scalpg_dump'
    },
    include_package_data=True,
    install_requires=requirements,
    entry_points='''
        [console_scripts]
        scalpg_dump=scalpg_dump.scalpg_dump:main
    ''',
    license="MIT license",
    zip_safe=False,
    keywords='scalpg_dump',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
